# rentcast-client
No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 1.0
- Package version: 1.0.1
- Generator version: 7.8.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python 3.7+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import rentcast_client
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import rentcast_client
```

### Tests

Execute `pytest` to run the tests.

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import rentcast_client
from rentcast_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://api.rentcast.io/v1
# See configuration.py for a list of all supported configuration parameters.
configuration = rentcast_client.Configuration(
    host = "https://api.rentcast.io/v1"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: sec0
configuration.api_key['sec0'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['sec0'] = 'Bearer'


# Enter a context with an instance of the API client
async with rentcast_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = rentcast_client.DefaultApi(api_client)
    zip_code = '29611' # str | A valid 5-digit US zip code (default to '29611')
    history_range = 6 # int | The time range for historical record entries, in months. Defaults to 12 if not provided (optional) (default to 6)

    try:
        # Market Statistics
        api_response = await api_instance.market_statistics(zip_code, history_range=history_range)
        print("The response of DefaultApi->market_statistics:\n")
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling DefaultApi->market_statistics: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *https://api.rentcast.io/v1*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*DefaultApi* | [**market_statistics**](docs/DefaultApi.md#market_statistics) | **GET** /markets | Market Statistics
*DefaultApi* | [**property_record_by_id**](docs/DefaultApi.md#property_record_by_id) | **GET** /properties/{id} | Property Record by Id
*DefaultApi* | [**property_records**](docs/DefaultApi.md#property_records) | **GET** /properties | Property Records
*DefaultApi* | [**property_records_random**](docs/DefaultApi.md#property_records_random) | **GET** /properties/random | Random Property Records
*DefaultApi* | [**rent_estimate_long_term**](docs/DefaultApi.md#rent_estimate_long_term) | **GET** /avm/rent/long-term | Rent Estimate
*DefaultApi* | [**rental_listing_long_term_by_id**](docs/DefaultApi.md#rental_listing_long_term_by_id) | **GET** /listings/rental/long-term/{id} | Rental Listing by Id
*DefaultApi* | [**rental_listings_long_term**](docs/DefaultApi.md#rental_listings_long_term) | **GET** /listings/rental/long-term | Rental Listings
*DefaultApi* | [**sale_listing_by_id**](docs/DefaultApi.md#sale_listing_by_id) | **GET** /listings/sale/{id} | Sale Listing by Id
*DefaultApi* | [**sale_listings**](docs/DefaultApi.md#sale_listings) | **GET** /listings/sale | Sale Listings
*DefaultApi* | [**value_estimate**](docs/DefaultApi.md#value_estimate) | **GET** /avm/value | Value Estimate


## Documentation For Models

 - [MarketStatistics200Response](docs/MarketStatistics200Response.md)
 - [MarketStatistics200ResponseRentalData](docs/MarketStatistics200ResponseRentalData.md)
 - [MarketStatistics200ResponseRentalDataDataByBedroomsInner](docs/MarketStatistics200ResponseRentalDataDataByBedroomsInner.md)
 - [MarketStatistics200ResponseRentalDataHistory](docs/MarketStatistics200ResponseRentalDataHistory.md)
 - [MarketStatistics200ResponseRentalDataHistory202309](docs/MarketStatistics200ResponseRentalDataHistory202309.md)
 - [MarketStatistics200ResponseRentalDataHistory202309DataByBedroomsInner](docs/MarketStatistics200ResponseRentalDataHistory202309DataByBedroomsInner.md)
 - [MarketStatistics200ResponseRentalDataHistory202310](docs/MarketStatistics200ResponseRentalDataHistory202310.md)
 - [MarketStatistics200ResponseRentalDataHistory202310DataByBedroomsInner](docs/MarketStatistics200ResponseRentalDataHistory202310DataByBedroomsInner.md)
 - [MarketStatistics200ResponseRentalDataHistory202311](docs/MarketStatistics200ResponseRentalDataHistory202311.md)
 - [MarketStatistics200ResponseRentalDataHistory202311DataByBedroomsInner](docs/MarketStatistics200ResponseRentalDataHistory202311DataByBedroomsInner.md)
 - [MarketStatistics200ResponseRentalDataHistory202312](docs/MarketStatistics200ResponseRentalDataHistory202312.md)
 - [MarketStatistics200ResponseRentalDataHistory202312DataByBedroomsInner](docs/MarketStatistics200ResponseRentalDataHistory202312DataByBedroomsInner.md)
 - [MarketStatistics200ResponseRentalDataHistory202401](docs/MarketStatistics200ResponseRentalDataHistory202401.md)
 - [MarketStatistics200ResponseRentalDataHistory202401DataByBedroomsInner](docs/MarketStatistics200ResponseRentalDataHistory202401DataByBedroomsInner.md)
 - [MarketStatistics200ResponseRentalDataHistory202402](docs/MarketStatistics200ResponseRentalDataHistory202402.md)
 - [PropertyRecords200ResponseInner](docs/PropertyRecords200ResponseInner.md)
 - [PropertyRecords200ResponseInnerFeatures](docs/PropertyRecords200ResponseInnerFeatures.md)
 - [PropertyRecords200ResponseInnerOwner](docs/PropertyRecords200ResponseInnerOwner.md)
 - [PropertyRecords200ResponseInnerOwnerMailingAddress](docs/PropertyRecords200ResponseInnerOwnerMailingAddress.md)
 - [PropertyRecords200ResponseInnerPropertyTaxes](docs/PropertyRecords200ResponseInnerPropertyTaxes.md)
 - [PropertyRecords200ResponseInnerPropertyTaxes2019](docs/PropertyRecords200ResponseInnerPropertyTaxes2019.md)
 - [PropertyRecords200ResponseInnerPropertyTaxes2020](docs/PropertyRecords200ResponseInnerPropertyTaxes2020.md)
 - [PropertyRecords200ResponseInnerPropertyTaxes2021](docs/PropertyRecords200ResponseInnerPropertyTaxes2021.md)
 - [PropertyRecords200ResponseInnerPropertyTaxes2022](docs/PropertyRecords200ResponseInnerPropertyTaxes2022.md)
 - [PropertyRecords200ResponseInnerPropertyTaxes2023](docs/PropertyRecords200ResponseInnerPropertyTaxes2023.md)
 - [PropertyRecords200ResponseInnerTaxAssessments](docs/PropertyRecords200ResponseInnerTaxAssessments.md)
 - [PropertyRecords200ResponseInnerTaxAssessments2019](docs/PropertyRecords200ResponseInnerTaxAssessments2019.md)
 - [PropertyRecords200ResponseInnerTaxAssessments2020](docs/PropertyRecords200ResponseInnerTaxAssessments2020.md)
 - [PropertyRecords200ResponseInnerTaxAssessments2021](docs/PropertyRecords200ResponseInnerTaxAssessments2021.md)
 - [PropertyRecords200ResponseInnerTaxAssessments2022](docs/PropertyRecords200ResponseInnerTaxAssessments2022.md)
 - [PropertyRecords200ResponseInnerTaxAssessments2023](docs/PropertyRecords200ResponseInnerTaxAssessments2023.md)
 - [RentEstimateLongTerm200Response](docs/RentEstimateLongTerm200Response.md)
 - [RentEstimateLongTerm200ResponseComparablesInner](docs/RentEstimateLongTerm200ResponseComparablesInner.md)
 - [RentalListingLongTermById200Response](docs/RentalListingLongTermById200Response.md)
 - [RentalListingsLongTerm200ResponseInner](docs/RentalListingsLongTerm200ResponseInner.md)
 - [SaleListingById200Response](docs/SaleListingById200Response.md)
 - [SaleListings200ResponseInner](docs/SaleListings200ResponseInner.md)
 - [ValueEstimate200Response](docs/ValueEstimate200Response.md)
 - [ValueEstimate200ResponseComparablesInner](docs/ValueEstimate200ResponseComparablesInner.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization


Authentication schemes defined for the API:
<a id="sec0"></a>
### sec0

- **Type**: API key
- **API key parameter name**: X-Api-Key
- **Location**: HTTP header


## Author




